require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_rossbuildingblock',
  dscmeta_resource_friendly_name: 'ROSSBuildingBlock',
  dscmeta_resource_name: 'VE_ROSSBuildingBlock',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'RESONEServiceStore',
  dscmeta_module_version: '3.2.0',
  docs: 'The DSC ROSSBuildingBlock resource type.
         Automatically generated from version 3.2.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_usehttps: {
      type: 'Optional[Boolean]',
      desc: 'Specifies connecting to the RES ONE Service Store API endpoint using TLS/SSL',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_server: {
      type: 'String',
      desc: 'RES ONE Service Store API hostname/endpoint',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_enabletransactions: {
      type: 'Optional[Boolean]',
      desc: 'Specifies imported service objects should be enabled',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_deletefromdisk: {
      type: 'Optional[Boolean]',
      desc: 'Delete the source building block file after import',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_identitydirector: {
      type: 'Optional[Boolean]',
      desc: 'Specifies connecting to the RES ONE Identity Director API endpoint',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_credential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'RES ONE Service Store API credential',
      behaviour: :parameter,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_path: {
      type: 'String',
      desc: 'RES ONE Service Store building block file path',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_noclobber: {
      type: 'Optional[Boolean]',
      desc: 'Specifies imported service objects should not overwrite existing objects',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
  },
)
