require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_rossclient',
  dscmeta_resource_friendly_name: 'ROSSClient',
  dscmeta_resource_name: 'VE_ROSSClient',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'RESONEServiceStore',
  dscmeta_module_version: '3.2.0',
  docs: 'The DSC ROSSClient resource type.
         Automatically generated from version 3.2.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'Absent']]",
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_catalogservicescredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'RES ONE Service Store Catalog Services password',
      behaviour: :parameter,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_catalogserviceshost: {
      type: 'String',
      desc: 'RES ONE Service Store Catalog Services host',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_version: {
      type: 'Optional[String]',
      desc: 'RES ONE Service Store component version to be installed, i.e. 8.0.3.0',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_path: {
      type: 'String',
      desc: 'File path containing the RES ONE Service Store MSIs or the literal path to the installer',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_productname: {
      type: 'Optional[String]',
      desc: 'Windows Installer Product Name',
      behaviour: :read_only,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_isliteralpath: {
      type: 'Optional[Boolean]',
      desc: 'Specified path is a literal file reference',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
  },
)
