require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_rossmanagementportalconfig',
  dscmeta_resource_friendly_name: 'ROSSManagementPortalConfig',
  dscmeta_resource_name: 'VE_ROSSManagementPortalConfig',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'RESONEServiceStore',
  dscmeta_module_version: '3.2.0',
  docs: 'The DSC ROSSManagementPortalConfig resource type.
         Automatically generated from version 3.2.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_enableapiendpoint: {
      type: 'Optional[Boolean]',
      desc: 'Configures the RES ONE Identity Directory REST API endpoint',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_applicationurl: {
      type: 'Optional[String]',
      desc: 'RES ONE Identity Director Management Portal Application/Callback Uri',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_credential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'RES ONE Service Store database Microsoft SQL username/password',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_clientid: {
      type: 'Optional[String]',
      desc: 'RES ONE Identity Broker Client ID',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_identitybrokerurl: {
      type: 'Optional[String]',
      desc: 'RES ONE Identity Broker Uri',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_path: {
      type: 'String',
      desc: 'RES ONE Service Store web management portal configuration file path',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_databasename: {
      type: 'String',
      desc: 'RES ONE Service Store database name',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_clientsecret: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'RES ONE Identity Broker Client shared secret',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'Absent']]",
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_databaseserver: {
      type: 'String',
      desc: 'RES ONE Service Store database server/instance name',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
